==> cscec5b-rmat-api-3.0.1-20221228.034820-116-sources.jar: com/ejianc/business/rmat/vo/ExitDetailVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
public class ExitDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long exitId; // 退场主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String memo; // 备注
    private Date stopDate; // 止租日
    private String def1; // 
    private String def2; // 
    private String def3; // 
    private String def4; // 
    private String def5; // 
    private BigDecimal applyNums; // 申请退场数量
    private BigDecimal exitNums; // 本次退场数量
    private BigDecimal exitNumsSum; // 累计退场数量
    private Integer type; // 行类型0-物资档案，1-验收，2-申请
    private BigDecimal checkNum; // 累计进场数量
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)

    private String state; // 状态
    private BigDecimal rentOutNum; // 计租退场数量
    private BigDecimal realOutNum; // 实物退场数量
    private BigDecimal rentRecordOutNum; // 计租退场档案数量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date exitDate; // 止租日期
    private Integer isTrue;//是否能编辑  不等于空能编辑
    private Long applyDetailId;//退场申请单明细id



    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getStopDate() {
        return stopDate;
    }

    public void setStopDate(Date stopDate) {
        this.stopDate = stopDate;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }
}

==> cscec5b-rmat-api-3.0.1-20240418.070812-303-sources.jar: com/ejianc/business/rmat/vo/ExitDetailVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
public class ExitDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long exitId; // 退场主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date stopDate; // 止租日
    private String def1; // 
    private String def2; // 
    private String def3; // 
    private String def4; // 
    private String def5; // 
    private BigDecimal applyNums; // 申请退场数量
    private BigDecimal exitNums; // 本次退场数量
    private BigDecimal exitNumsSum; // 累计退场数量
    private Integer type; // 行类型0-物资档案，1-验收，2-申请
    private BigDecimal checkNum; // 累计进场数量
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)

    private String state; // 状态
    private BigDecimal rentOutNum; // 计租退场数量
    private BigDecimal realOutNum; // 实物退场数量
    private BigDecimal rentRecordOutNum; // 计租退场档案数量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date exitDate; // 止租日期
    private Integer isTrue;//是否能编辑  不等于空能编辑
    private Long applyDetailId;//退场申请单明细id

    private List<ExitSupplierVO> exitSupplierList = new ArrayList<>(); // 退场单劳务队明细


    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getStopDate() {
        return stopDate;
    }

    public void setStopDate(Date stopDate) {
        this.stopDate = stopDate;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }

    public BigDecimal getRentRecordOutNum() {
        return rentRecordOutNum;
    }

    public void setRentRecordOutNum(BigDecimal rentRecordOutNum) {
        this.rentRecordOutNum = rentRecordOutNum;
    }

    public List<ExitSupplierVO> getExitSupplierList() {
        return exitSupplierList;
    }

    public void setExitSupplierList(List<ExitSupplierVO> exitSupplierList) {
        this.exitSupplierList = exitSupplierList;
    }
}
